pref("browser.aboutConfig.showWarning", false);
pref("browser.download.showTorWarning", false);
pref("browser.tabs.warnOnClose", false);
pref("devtools.chrome.enabled", true);
pref("intl.language_notification.shown", true);
pref("privacy.prioritizeonions.showNotification", false);
